@@ -1,14 +1,14 @@
 from public import public as _public
 
-from flufl.i18n.types import (
-    RuntimeTranslator, TranslationStrategy, TranslationContextManager)
+from flufl.i18n._application import Application
 from flufl.i18n._expand import expand
 from flufl.i18n._registry import registry
-from flufl.i18n._strategy import SimpleStrategy, PackageStrategy
-from flufl.i18n._application import Application
+from flufl.i18n._strategy import PackageStrategy, SimpleStrategy
+from flufl.i18n.types import (
+    RuntimeTranslator, TranslationContextManager, TranslationStrategy)
 
 
-__version__ = '3.0'
+__version__ = '3.1.2'
 
 
 _public(
